@@ -10,7 +10,7 @@ our $FFFD = chr(0xFFFD);
 
 # ABSTRACT: MarpaX::ESLIF::ECMA404 Value Interface
 
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
@@ -79,8 +79,10 @@ sub unicode {
       if (($high >= 0xD800) && ($high <= 0xDBFF) && ($low >= 0xDC00) && ($low <= 0xDFFF)) {
         #
         # Yes.
+        # This is evaled for one reason only: some old versions of perl may croak with special characters like
+        # "Unicode character 0x10ffff is illegal"
         #
-        $result .= chr((($high - 0xD800) * 0x400) + ($low - 0xDC00) + 0x10000);
+        $result .= eval {chr((($high - 0xD800) * 0x400) + ($low - 0xDC00) + 0x10000)} // $FFFD;
         splice(@hex, 0, 2)
       } else {
         #
@@ -188,7 +190,7 @@ MarpaX::ESLIF::ECMA404::ValueInterface - MarpaX::ESLIF::ECMA404 Value Interface
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
